@@ -1,8 +1,6 @@
 import click
-# from click._compat import get_text_stderr
-# from click.utils import echo
 from .logger import Logger
-from dsocli.constants import *
+from .cli_constants import *
 
 class MuOption(click.Option):
     def __init__(self, *args, **kwargs):
