@@ -1,9 +1,7 @@
 import os
 import re
 import imp
-import importlib.util
-import sys
-from .config import Config
+from .config import Configs
 from .constants import *
 from .logger import Logger
 from .exceptions import DSOException
@@ -27,25 +25,25 @@ class StoreProvider(ProviderBase):
         raise NotImplementedError()
 
 
-class ProviderManagerClass():
+class ProviderManager():
     __providers = {}
 
     # def load_all_providers(self):
-    #     __import__(Config.root_path + 'lib/dso/provider')
+    #     __import__(Configs.root_path + 'lib/dso/provider')
     #     # importdir.do(os.path.dirname(__file__)+'/secret_providers', globals())
     #     # importdir.do(os.path.dirname(__file__)+'/template_providers', globals())
 
     def load_provider(self, provider_id):
         Logger.debug(f"Loading provider '{provider_id}'...")
-        providerPackagePath = os.path.join(Config.install_path, 'provider', provider_id)
+        providerPackagePath = os.path.join(Configs.install_path, 'provider', provider_id)
         if not os.path.exists(providerPackagePath):
-            raise DSOException(f"Provider '{provider_id}' not found.")
+            raise DSOException(f"Providers '{provider_id}' not found.")
         imp.load_package(provider_id, providerPackagePath)
 
     def register(self, provider: ProviderBase):
         if not provider.id in self.__providers:
             self.__providers[provider.id] = provider
-            Logger.debug(f"Provider registered: id ={provider.id}")
+            Logger.debug(f"Providers registered: id ={provider.id}")
 
     def get_provider(self, provider_id):
         if not provider_id in self.__providers:
@@ -58,18 +56,18 @@ class ProviderManagerClass():
             raise DSOException(f"No provider has registered for '{provider_id}'.")
 
     def ParameterProvider(self):
-        if not Config.parameter_provider:
+        if not Configs.parameter_provider:
             raise DSOException('Parameter provider has not been set.')
-        return self.get_provider('parameter/' + Config.parameter_provider)
+        return self.get_provider('parameter/' + Configs.parameter_provider)
 
     def TemplateProvider(self):
-        if not Config.template_provider:
+        if not Configs.template_provider:
             raise DSOException('Template provider has not been set.')
-        return self.get_provider('template/' + Config.template_provider)
+        return self.get_provider('template/' + Configs.template_provider)
 
     def SecretProvider(self):
-        if not Config.secret_provider:
+        if not Configs.secret_provider:
             raise DSOException('Secret provider has not been set.')
-        return self.get_provider('secret/' + Config.secret_provider)
+        return self.get_provider('secret/' + Configs.secret_provider)
 
-ProviderManager = ProviderManagerClass()
+Providers = ProviderManager()
