@@ -3,15 +3,12 @@ import os
 import re
 import jinja2
 from jinja2 import meta
-from shutil import rmtree
-from pathlib import Path
 from .constants import *
-from .config import Config
-from .providers import StoreProvider, ProviderManager
+from .config import Configs
+from .providers import StoreProvider, Providers
 from .parameters import Parameters
 from .secrets import Secrets
 from .logger import Logger
-from .file_utils import clean_directory
 from .dict_utils import merge_dicts, deflatten_dict
 from .exceptions import DSOException
 from .stages import Stages
@@ -19,28 +16,25 @@ from .stages import Stages
 class TemplateProvider(StoreProvider):
     def list(self):
         raise NotImplementedError()
-
     def add(self, key, content, render_path):
         raise NotImplementedError()
-
     def delete(self, key, starts_with):
         raise NotImplementedError()
-
     def get(self, key):
         raise NotImplementedError()
 
-class TemplatesClass():
+class TemplateManager():
 
     @property
     def default_render_path(self):
-        return Config.working_dir
+        return Configs.working_dir
 
     def list(self, uninherited):
-        project = Config.project
-        application = Config.application
-        provider = ProviderManager.TemplateProvider()
+        project = Configs.project
+        application = Configs.application
+        provider = Providers.TemplateProvider()
         Logger.info(f"Start listing templates: project={project}, application={application}")
-        renderPaths = Config.get_template_render_paths()
+        renderPaths = Configs.get_template_render_paths()
         renderBasePath = Templates.default_render_path
         response = provider.list(project, application, uninherited)
         for template in response['Templates']:
@@ -58,11 +52,11 @@ class TemplatesClass():
 
     def add(self, key, content, render_path):
         self.validate_key(key)
-        project = Config.project
-        application = Config.application
-        provider = ProviderManager.TemplateProvider()
+        project = Configs.project
+        application = Configs.application
+        provider = Providers.TemplateProvider()
         # if '..' in render_path:
-        #     raise DSOException(CLI_MESSAGES['InvalidRenderPath'].format(render_path))
+        #     raise DSOException(MESSAGES['InvalidRenderPath'].format(render_path))
         if render_path == '.' or render_path == './':
             render_path = os.path.join(self.default_render_path, key)
         else:
@@ -71,9 +65,9 @@ class TemplatesClass():
             if '*' in render_path:
                 render_path = render_path.replace('*', os.path.basename(key))
         if not re.match('^[A-Za-z0-9._/$-]+$', render_path):
-            raise DSOException(CLI_MESSAGES['InvalidRenderPath'].format(render_path))
+            raise DSOException(MESSAGES['InvalidRenderPath'].format(render_path))
         if os.path.isdir(render_path):
-            raise DSOException(CLI_MESSAGES['InvalidRenderPathExistingDir'].format(render_path))
+            raise DSOException(MESSAGES['InvalidRenderPathExistingDir'].format(render_path))
         if os.path.isabs(render_path):
             Logger.warn(f"Render path {render_path} is not releative to the application root.")
         else:
@@ -85,63 +79,63 @@ class TemplatesClass():
             result['RenderTo'] = render_path
         finally:
             if os.path.abspath(render_path) == os.path.abspath(os.path.join(self.default_render_path, key)):
-                Config.unregister_template_custom_render_path(key)
+                Configs.unregister_template_custom_render_path(key)
             else:
-                Config.register_template_custom_render_path(key, render_path)
+                Configs.register_template_custom_render_path(key, render_path)
         return result
 
     def get(self, key):
         # self.validate_key(key)
-        project = Config.project
-        application = Config.application
-        provider = ProviderManager.TemplateProvider()
+        project = Configs.project
+        application = Configs.application
+        provider = Providers.TemplateProvider()
         Logger.info(f"Start getting template: project={project}, application={application}, key={key}")
         return provider.get(project, application, key)
 
     def delete(self, key):
         # self.validate_key(key)
-        project = Config.project
-        application = Config.application
-        provider = ProviderManager.TemplateProvider()
+        project = Configs.project
+        application = Configs.application
+        provider = Providers.TemplateProvider()
         Logger.info(f"Start deleting template: project={project}, application={application}, key={key}")
         try:
             result = provider.delete(project, application, key)
         finally:
-            Config.unregister_template_custom_render_path(key)
+            Configs.unregister_template_custom_render_path(key)
         return result
 
     def validate_key(self, key):
-        provider = ProviderManager.TemplateProvider()
+        provider = Providers.TemplateProvider()
         Logger.info("Start validating template key...")
         return provider.validate_key(key)
 
     def render(self, stage, limit=''):
-        project = Config.project
-        application = Config.application
+        project = Configs.project
+        application = Configs.application
         Logger.info(f"Start rendering templates: project={project}, application={application}, stage={Stages.shorten(stage)}")
 
         if Stages.is_default(stage):
             Logger.warn("No stage has been provided for rendering templates, using 'default'.")
 
-        Logger.info(CLI_MESSAGES['LoadingParameters'])
+        Logger.info("Loading parameters...")
         parameters = Parameters.list(stage, uninherited=False)
 
         merged = deflatten_dict({x['Key']: x['Value'] for x in parameters['Parameters']})
 
-        Logger.info(CLI_MESSAGES['LoadingSecrets'])
+        Logger.info("Loading secrets...")
         secrets = Secrets.list(stage, uninherited=False, decrypt=True)
 
-        Logger.info(CLI_MESSAGES['MerginParameters'])
+        Logger.info("Merging parameters...")
         merge_dicts(deflatten_dict({x['Key']: x['Value'] for x in secrets['Secrets']}), merged)
 
-        provider = ProviderManager.TemplateProvider()
-        Logger.info(CLI_MESSAGES['LoadingTemplates'])
+        Logger.info("Loading templates...")
+        provider = Providers.TemplateProvider()
         templates = provider.list(project, application, uninherited=False)['Templates']
-        renderPaths = Config.get_template_render_paths()
+        renderPaths = Configs.get_template_render_paths()
 
         jinja_env = jinja2.Environment(undefined=jinja2.StrictUndefined)
 
-        Logger.info(CLI_MESSAGES['RenderingTemplates'])
+        Logger.info("Rendering templates...")
         rendered = []
         for item in templates:
             key = item['Key']
@@ -184,4 +178,4 @@ class TemplatesClass():
         return rendered
 
 
-Templates = TemplatesClass()
\ No newline at end of file
+Templates = TemplateManager()
\ No newline at end of file
